Struct ZcosmicOutputHeadV1

pub struct ZcosmicOutputHeadV1 { /* private fields */ }
Available on crate feature wayland and Linux only.
Output extension object

Extension to zwlr_output_head_v1.

Adds additional read-only properties.

Properties sent via this interface are applied atomically via the wlr_output_manager.done event. No guarantees are made regarding the order in which properties are sent.

See also the Request enum for this interface.

Implementations

Source

impl ZcosmicOutputHeadV1

pub fn scale_1000(&self, scale_1000: i32)

current scale

This events describes the scale of the head in the global compositor space multiplied by 1000 for additional precision.

It is only sent if the output is enabled.

pub fn mirroring(&self, name: Option<String>)

mirroring other output

This events describes that the head is mirroring another. In these cases name contains the unique name of the matching zwlr_output_head_v1. If the name is null, no head is being mirrored onto this one.

For mirrored heads the position-event is meaningless.

It is only sent if the output is enabled.

pub fn adaptive_sync_available(&self, available: AdaptiveSyncAvailability)

is adaptive_sync available for this head

This events describes if adaptive_sync is available for this head.

It is only sent if the output is enabled.

pub fn adaptive_sync_ext(&self, state: AdaptiveSyncStateExt)

current adaptive_sync state

This events describes the adaptive_sync state of this head.

It is only sent if the output is enabled.

pub fn xwayland_primary(&self, state: u32)

is this head configured as the primary for xwayland

This event describes if this head is advertised as the primary output via randr to Xwayland.

At most one output is marked primary, but it is not guaranteed that any output is marked. It is only sent if the output is enabled.